# Contributor Code of Conduct

**All creatures are welcome**: We aim to create a safe space for all community members, regardless of their age, race, gender, sexual orientation, physical appearance or disability, choice of text editor, or any other qualities by which living beings can be discriminated.

**Be excellent to each other**: We do not tolerate verbal or physical harrassment, violence or intimidation.

We do not tolerate life forms who refuse to share this openness and respect towards others: Creatures that are not excellent to others are not welcome.

If you are made uncomfortable as a community member, please let us know: You can contact [julian.arenas.guerrero@upm.es](mailto:julian.arenas.guerrero@upm.es).

#### Attribution

This Code of Conduct is adapted from the [CCC event CoC](https://www.ccc.de/en/updates/2016/a-reminder-to-be-excellent-to-each-other).
